#[non_exhaustive]pub enum ChatMemberStatus {
Creator,
Administrator,
Member,
Restricted,
Left,
Kicked,
Other,
}Expand description
Chat member status as returned by getChatMember.
Only the status variants relevant to admin checks are represented. Any
unrecognised status string is captured by the Other variant.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Creator
The user is the chat creator.
Administrator
The user is an administrator.
Member
The user is a regular member.
Restricted
The user is restricted.
Left
The user has left the chat.
Kicked
The user was kicked or banned.
Other
Unknown or future status value.